## Product details

Suitable for small dogs The overall size of this plastic dog house is 28in (L) 26in (W) 28in (H), which can be suitable for small dogs such as Pomeranians, Fa fight, Teddy, etc. Strong & Durable Our dog house is fastened with snaps and screws to ensure the stability of the overall structure. A adult can easily sit on the roof without crushing the house. The box contains two nails you can also use to fix the dog house on the ground. Outdoor Dog House Our plastic dog house is ideal for use in the backyard, patio, deck, etc. Double air vents ensure the circulation of fresh air and keep your dog cool in summer. Besides, our dog house is made of heat-insulating materials your pet will feel warmer if you put a blanket on the house in winter. Easy to assemble & waterproof & easy to clean simple tools, complete parts, clasp design, and screw fixation. It only takes an adult half an hour to assemble it. Sealed connection and elevated floor to protect your dog from rain. With a detachable roof, it is very convenient for you to clean the dog house.

Our dog house is made of environmentally friendly PP material, which is durable, sun-proof and waterproof. Perfect for use in the backyard garden, providing a perfect home for your pet.
Our plastic dog house provides a comfortable and superior event space
Smooth surfaces and detachable roof make this outdoor dog house easy to clean.
Our large dog house is easy to assemble, instructions are included in the box. According to instructions, can complete the assembly in about half an hour.
Raised floors and waterproof materials keep the dog house from leaking and protect your pet from rain.
Overall Dimensions: 28in(L)×26.2in(W)×28 in(H)
Net Weight：14.61pounds
Color: Brown
Material: PP
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Pet kennel & crate type
Outdoor Kennel
Animal type
Dog
Height
28 in
Size descriptor
Small
More details
Warranty

## Warranty information
90 Days
